@@ -1,5 +1,6 @@
 import os
 from time import time
+import platform
 
 
 def _fish_history_file_location():
@@ -17,7 +18,7 @@ def fish_history_file_lines():
     history_file = _fish_history_file_location()
     if history_file is None:
         return []
-    with open(history_file, 'r') as history:
+    with open(history_file, "r") as history:
         lines = history.readlines()
         return lines
 
@@ -42,12 +43,15 @@ def zsh_history_file_lines():
 
 
 def _get_history_line(command_script):
-    return u'- cmd: {}\n  when: {}\n'.format(command_script, int(time()))
+    return "- cmd: {}\n  when: {}\n".format(command_script, int(time()))
 
 
 def save(cmd):
+    if platform.system().lower().startswith("win"):
+        return
+
     history_file = _fish_history_file_location()
-    if os.path.isfile(history_file):
-        with open(history_file, 'a') as history:
+    if history_file and os.path.isfile(history_file):
+        with open(history_file, "a") as history:
             entry = _get_history_line(cmd)
             history.write(entry)
